/**
 * Test for uri.c
 * @author Christian Grothoff
 * @file applications/afs/esed2/uritest.c
 */

#include "platform.h"
#include "gnunet_util.h"
#include "gnunet_afs_esed2.h"

static int testKeyword() {
  char ** keywords;
  char * uri;

  if (SYSERR != parseKeywordURI("gnunet://afs/++",
				&keywords))
    return 1;
  if (2 != parseKeywordURI("gnunet://afs/foo+bar",
			   &keywords))
    return 1;
  if ( (0 != strcmp("foo", keywords[0])) ||
       (0 != strcmp("bar", keywords[1])))
    return 1;
  uri = createKeywordURI(keywords, 2);
  if ( (0 != strcmp(uri,
		    "gnunet://afs/foo+bar")) &&
       (0 != strcmp(uri,
		    "gnunet://afs/search/foo+bar")) )
    return 1;
  FREE(uri); 
  uri = createKeywordURI(keywords, 1);
  if ( (0 != strcmp(uri,
		    "gnunet://afs/foo")) &&
       (0 != strcmp(uri,
		    "gnunet://afs/search/foo")) )
    return 1;
  FREE(uri);
  FREE(keywords[0]);
  FREE(keywords[1]);
  FREE(keywords);
  return 0;
}

static int testNamespace(int i) {
  char * uri;
  HashCode160 ns1;
  HashCode160 ns2;
  HashCode160 id1;
  HashCode160 id2;
  
  memset(&ns1, i, sizeof(FileIdentifier));
  memset(&id1, 255-i, sizeof(FileIdentifier));
  uri = createSubspaceURI(&ns1, &id1);
  if (OK != parseSubspaceURI(uri,
			     &ns2,
			     &id2))
    return 1;
  FREE(uri);
  if ( (0 != memcmp(&id1, &id2, sizeof(HashCode160))) ||
       (0 != memcmp(&ns1, &ns2, sizeof(HashCode160))) )
    return 1;  
  return 0;
}

static int testFile(int i) {
  char * uri;
  FileIdentifier fi;
  FileIdentifier fo;
  
  memset(&fi, i, sizeof(FileIdentifier));
  uri = createFileURI(&fi);
  if (OK != parseFileURI(uri,
			 &fo))
    return 1;
  FREE(uri);
  if (0 != memcmp(&fi, &fo, sizeof(FileIdentifier)))
    return 1;  
  return 0;
}

int main(int argc, char * argv[]) {
  int failureCount = 0;
  int i;
  
  failureCount += testKeyword();
  for (i=0;i<255;i++) {
    failureCount += testNamespace(i);
    failureCount += testFile(i);
  }

  if (failureCount == 0)
    return 0;
  else 
    return 1;
} 

/* end of uritest.c */
